import maxflow.MaxFlow;
import org.graphstream.graph.Edge;
import org.graphstream.graph.Graph;
import org.graphstream.graph.Node;
import org.graphstream.graph.implementations.DefaultGraph;
import org.graphstream.stream.file.FileSource;
import org.graphstream.stream.file.FileSourceDGS;

import java.io.*;

public class Autoroutes {

    public static void main(String[] args) {

        System.setProperty("org.graphstream.ui", "swing");

        String filePath = "resources/autoroute.dgs";
        Graph g = new DefaultGraph("autoroutes");
        FileSource fs = new FileSourceDGS();

        fs.addSink(g);

        try {
            fs.readAll(filePath);
        } catch( IOException e) {
            System.err.println("Error while generating graph");
            e.printStackTrace();
            System.exit(1);
        } finally {
            fs.removeSink(g);
        }

        MaxFlow mf = new MaxFlow();
        mf.setCapacityAttribute("cap");
        mf.init(g);
        mf.setSource(g.getNode("A"));
        mf.setSink(g.getNode("I"));
        mf.compute();

        g.edges().forEach((Edge e) -> {
            e.setAttribute("ui.style", "text-size: 15; text-alignment: along;");
            double flow = mf.getFlow(e);
            double cap = mf.getCapacity(e);
            e.setAttribute("ui.label", String.format("%.0f/%.0f", flow, cap));
            if (cap == flow) e.setAttribute("ui.style", "text-size: 15; text-alignment: along; fill-color: red;");
        });

        g.nodes().forEach((Node n) -> {
            n.setAttribute("ui.label", n.toString());
            n.setAttribute("ui.style", "fill-color: white;"
                    + "stroke-mode: plain;"
                    + "stroke-width: 2;"
                    + "stroke-color: black;"
                    + "size: "+ "24, 24;");
        });

        g.display();
    }
}
